@@ -4,7 +4,7 @@ from .Aurora import Aurora
 # For the sake of init_app
 try:
     from .Controller import Controller
-    from .View import View as Template
+    from .Template import Template
     from .Forms import Forms
     from .Model import Model
 
@@ -15,5 +15,5 @@ except:
     pass
 
 # Descriptions
-__version__ = '0.8.19'
+__version__ = '0.8.20'
 __author__ = '<https://github.com/heminsatya>'
